IsNormalized

Enum IsNormalized 

pub enum IsNormalized {
    Yes,
    No,
    Maybe,
}
QuickCheck quickly determines if a string is normalized, it can return Maybe

The QuickCheck algorithm can quickly determine if a text is or isn’t normalized without any allocations in many cases, but it has to be able to return Maybe when a full decomposition and recomposition is necessary.

Variants



Yes

The text is definitely normalized.



No

The text is definitely not normalized.



Maybe

The text may be normalized.